<?php

				
/*
 * Copyright  2004 by
 * Tilo Kussatz <http://www.kussatz.com>
 * and Steve Nelson <http://www.thegoldenmean.com>
 *
 * This script must be accompanied by the
 * ID3v2 tag reading class by Daniel Martinez-Morales:
 * http://phpclasses.php-start.de/browse/package/640.html
 *
 * This code is released under the GNU LGPL; see the included lgpl.txt.
 *
 * Purpose: This script requests some of the information the ID3v2 class
 * extracts and calcuates from an MP3 file or files, and formats that information
 * into XML format which is read by a Macromedia Flash-based MP3 player
 *
 */
error_reporting(E_ALL ^ E_NOTICE);
				
include_once("id3v2.php");
	
$mp3Info = new id3v2();
	
// Set the directory which contains the MP3 files. Don't forget the trailing slash!
// "./" is the directory this PHP file lives in.
$dir = './';
	
$counter = 0;
$handle = opendir($dir);
	
// Loop through all the files found in this directory
while (false !== ($file = readdir($handle))) {
	
	// Ignore any types of subdirectories and process files with ".mp3" extension only
	if (!is_dir($file) && eregi('(.mp3)$', $file)) {
	
		// Extract ID3 information from current file
		$mp3Info->GetInfo($dir.$file);
	
		// Collect information about the current song and add it to the $mp3List[] array
		// Preferably using ID3v2 information, otherwise ID3v1 data if available
	
		// Step 1 - the "artist" ID3 info:
		if (!empty($mp3Info->id3v2Info['TP1']['info'][0]['Value']))
			$mp3List[$counter]['artist'] = $mp3Info->id3v2Info['TP1']['info'][0]['Value'];
		elseif (!empty($mp3Info->id3v2Info['TPE1']['info'][0]['Value']))
			$mp3List[$counter]['artist'] = $mp3Info->id3v2Info['TPE1']['info'][0]['Value'];
		elseif (!empty($mp3Info->id3v1Info['artist']))
			$mp3List[$counter]['artist'] = $mp3Info->id3v1Info['artist'];
		else
			$mp3List[$counter]['artist'] = 'artist not available';
	
		// Step 2 - the "title" ID3 info:
		if (!empty($mp3Info->id3v2Info['TT2']['info'][0]['Value']))
			$mp3List[$counter]['title'] = $mp3Info->id3v2Info['TT2']['info'][0]['Value'];
		elseif (!empty($mp3Info->id3v2Info['TIT2']['info'][0]['Value']))
			$mp3List[$counter]['title'] = $mp3Info->id3v2Info['TIT2']['info'][0]['Value'];
		elseif (!empty($mp3Info->id3v1Info['title']))
			$mp3List[$counter]['title'] = $mp3Info->id3v1Info['title'];
		else
			$mp3List[$counter]['title'] = 'title not available';
	
		// Step 3 - the "album" ID3 info:
		if (!empty($mp3Info->id3v2Info['TAL']['info'][0]['Value']))
			$mp3List[$counter]['album'] = $mp3Info->id3v2Info['TAL']['info'][0]['Value'];
		elseif (!empty($mp3Info->id3v2Info['TALB']['info'][0]['Value']))
			$mp3List[$counter]['album'] = $mp3Info->id3v2Info['TALB']['info'][0]['Value'];
		elseif (!empty($mp3Info->id3v1Info['album']))
			$mp3List[$counter]['album'] = $mp3Info->id3v1Info['album'];
		else
			$mp3List[$counter]['album'] = 'album not available';
	
		// Step 4 - next extract PlayTime for progress bar and scrubber
		// Get it in milliseconds to match position property in ActionScript:
		$mp3List[$counter]['playtime'] = floor($mp3Info->mpegInfo['PlaySeconds']*1000);
	
		// Step 5 - get file size, to use with graphical preload bar
		$mp3List[$counter]['filesize'] = filesize($dir.$file);
	
		// Step 6 - the file name:
		$mp3List[$counter]['filename'] = 'tracks/' . $file;
	
		// That's it for this file - on to the next one!
		$counter++;
	}
}
closedir($handle);
	
	
// Sort the $mp3List array
// ( Slightly more complicated than I would have thought as it is multidimensional; see    
//     * http://php.net/array-multisort#46278 and
//     * http://php.net/usort )
	
function compare($a, $b) {
	// Case insensitive string comparison using a "natural order" algorithm
	// The array can be sorted by:
	//   'filename', 'artist', 'title', 'album', 'playtime', 'filesize'
	return strnatcasecmp($a['filename'], $b['filename']);
}
usort($mp3List, "compare"); 
	
	
// Now that all the necessary data has been collected and sorted, let's output the XML:
	
// Print opening XML tags
echo('<?xml version="1.0" encoding="UTF-8" ?>' . "\n");
echo('  <songs>' . "\n");
	
foreach($mp3List as $mp3) {
	
	// Build the <song> XML tag for the current song
	echo '    <song artist="' . $mp3['artist'] . '" title="' . $mp3['title'] . '" album="' . $mp3['album'] . '" playtime="' . $mp3['playtime'] . '" filesize="' . $mp3['filesize'] . '" url="' . $mp3['filename'] . '" />' . "\n";
		
}
		
		
// Print closing tag - we're done!
echo('  </songs>' . "\n");


?>
